@@ -4,31 +4,33 @@ const common = require('./webpack.common.js');
 const { stylePaths } = require('./stylePaths');
 const MiniCssExtractPlugin = require('mini-css-extract-plugin');
 const TerserJSPlugin = require('terser-webpack-plugin');
+const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
 
 module.exports = merge(common('production'), {
   mode: 'production',
-  devtool: 'source-map',
-  optimization: {
-    minimizer: [
-      new TerserJSPlugin({}),
+  devtool: 'nosources-source-map',
+  module: {
+    rules: [
+      {
+        test: /\.css$/,
+        include: [...stylePaths],
+        use: [{ loader: MiniCssExtractPlugin.loader }, { loader: 'css-loader' }],
+      },
     ],
   },
+  optimization: {
+    minimizer: [new TerserJSPlugin({}), `...`, new CssMinimizerPlugin()],
+    sideEffects: true,
+  },
   plugins: [
     new MiniCssExtractPlugin({
       filename: '[name].css',
       chunkFilename: '[name].bundle.css',
     }),
-  ],
-  module: {
-    rules: [
-      {
-        test: /\.css$/,
-        include: [...stylePaths],
-        use: [
-          { loader: MiniCssExtractPlugin.loader },
-          { loader: 'css-loader' },
-        ],
+    new CssMinimizerPlugin({
+      minimizerOptions: {
+        preset: ['default', { mergeLonghand: false }],
       },
-    ],
-  },
+    }),
+  ],
 });
